@@ -202,6 +202,9 @@ class CustomDataset(Dataset):
 
     def __len__(self):
         return len(self.image_name)
+    
+    def file_name(self):
+        return self.image_name
             
     def __getitem__(self, idx):
         info_file = open(os.path.join(self.root_dir,self.info_name[idx]), 'rb')
