@@ -10,7 +10,9 @@ import SimpleITK as sitk
 import time
 import os
 
+
 def get_pad_images(images, patch_size):
+    #이미지가 patch 보다 작을 경우 padding
     images = torch.tensor(images)
     if len(patch_size) == 3:
         image_shape = torch.tensor([images.shape[-3], images.shape[-2], images.shape[-1]])
@@ -39,14 +41,16 @@ def get_pad_images(images, patch_size):
     return images
 
 def get_coords_arr(images, patch_size, step_size):
+    #image와 patch, step size를 통해 patch를 뽑는 위치를 grid 단위로 나타냄. 
     grid_list = []
     image_shape = torch.tensor([images.shape[-3], images.shape[-2], images.shape[-1]])
     for i in range(3):
         step = 1+(image_shape[i] - patch_size[i])/(patch_size[i] * step_size[i])
         if step < 1:
             print('step is zero')
-            step = 1
+            step = 1.0
         grid_list.append(torch.arange(step))
+    print(grid_list)
     grid_x, grid_y, grid_z = torch.meshgrid(*grid_list)
     grid_x = torch.round(grid_x * step_size[0] * patch_size[0]).long()
     grid_y = torch.round(grid_y * step_size[1] * patch_size[1]).long()
@@ -70,19 +74,24 @@ def get_coords_arr(images, patch_size, step_size):
 
 
 def get_patch_from_coords(image, patch_coords, index):
+    #위의 함수에서 얻어진 image당 patch의 coords에서 image와 coords가 주어졌을 대 patch를 뽑아냄
     for i in range(image.shape[0]):
         if i == 0:
-            result = image[0][torch.meshgrid(*patch_coords[index])].unsqueeze(0)
+            patch = image[0][torch.meshgrid(*patch_coords[index])].unsqueeze(0)
         else:
-            result = torch.cat((result, image[i][torch.meshgrid(*patch_coords[index])].unsqueeze(0)))
-    return result
+            patch = torch.cat((patch, image[i][torch.meshgrid(*patch_coords[index])].unsqueeze(0)))
+    return patch
 
 def change_value_from_coords(image, patch_coords, index, patch):
+    #patch의 값으로 image와 해당하는 coords 의 값을 바꿈
     for i in range(image.shape[0]):
         image[i][torch.meshgrid(*patch_coords[index])] += patch[i]
     return image
 
+
 class CC_Remover(object):
+    # remain num => 남길 connected components label의 수
+    # frequency order => connected component labeling 된 것 중 택할 빈도 수를 정함. 1은 보통 background 임.
     def __init__(self, remain_num = 2, frequency_order = [2,3]):
         self.remain_num = remain_num
         self.frequency_order = frequency_order
@@ -100,6 +109,14 @@ class CC_Remover(object):
         return result
 
 class InferenceV2(object):
+    """
+    dataset : torch.utils.data 의 dataset 또는 해당 class를 상속받은 개체.
+    patch_size : inference 시에 적용 할 patch size를 설정
+    n_classes : softmax output의 channel 수
+    mode : 저장할 데이터셋 포멧 npy와 nifti만 지원 됨.
+    deep_supervision : 모델에 deep_supervision이 적용 될 경우, True
+    padding : patch size에 맞게 padding
+    """
     def __init__(self, dataset, model, patch_size, n_classes, mode = 'npy and nifti', step_size = [0.5, 0.5, 0.5], postprocessing = None, device = None,
                  batch_size = 1, gaussian_filter = False, deep_supervision = False, save_path = None, arg_max = False, padding = False, is_2d = False):
         self.dataset = dataset
@@ -120,6 +137,7 @@ class InferenceV2(object):
         self.is_2d = is_2d
     
     def valid_run(self):
+        #전체 데이터에 대해 inference 시작.
         print('start valid run')
         final_score = []
         self.model = self.model.eval()
@@ -138,7 +156,6 @@ class InferenceV2(object):
             result = self.get_result(image, data_index, current_name)
             dice_score = []
             for i in range(1, self.n_classes):
-                print("seg shape : ", seg.shape)
                 temp_seg = (seg == i).long()
                 temp_img = (result == i).long()
                 intersection = (temp_seg * temp_img).sum()
@@ -191,12 +208,12 @@ class InferenceV2(object):
         return "Done"
     
     def get_result(self, image, data_index = None, current_name = None):
+        # 각 이미지 별로 result를 구함.
         if self.padding:
             image = get_pad_images(image, self.patch_size)
         coords = get_coords_arr(image, self.patch_size, self.step_size)
         self.model.eval()
 
-        print('get result')
         for coords_index in range(len(coords)):
             if coords_index == 0:
                 patch_bundle = get_patch_from_coords(image, coords, coords_index).unsqueeze(0)
@@ -216,7 +233,6 @@ class InferenceV2(object):
             output = torch.softmax(output, dim = 1)
             output = output.cpu()
             for batch_index in range(mini_batch_index.shape[0]):
-                print('result shape', result.shape, 'coords x max', coords[mini_batch_index[batch_index]][0].max(), coords[mini_batch_index[batch_index]][1].max(), coords[mini_batch_index[batch_index]][2].max(), 'batch index', batch_index, 'mini batch index', mini_batch_index[batch_index])
                 result = change_value_from_coords(result, coords, mini_batch_index[batch_index], output[batch_index])
         
         if self.save_path != None:
@@ -236,7 +252,6 @@ class InferenceV2(object):
     
             for i in range(len(classes)):
                 class_map = (result.numpy() == classes[i])
-                print("class_map shape : ", class_map.shape)
                 class_map = self.postprocessing(class_map)
                 new_result += class_map * i
             result = new_result
@@ -271,7 +286,6 @@ class Inference2D(InferenceV2):
         return super().make_dir(save_path)
 
     def get_value_by_index(self, tensor, index):
-        print(tensor.shape)
         if self.axis == 0:
             result = tensor[:, index]
         elif self.axis == 1:
