@@ -4,15 +4,17 @@ import torch.nn.functional as F
 import numpy as np
 import math
 
+
 class Batch_Affine_3D(object):
-    def __init__(self, degree = [30, 30, 30], axis = [0,1,2], scale = [0.7, 1.4], use_gpu = True, device = None, is_random = True):
+    def __init__(self, degree = [30, 30, 30], axis = [0,1,2], scale = [0.7, 1.4], use_gpu = True, device = None, is_random = True, pad_value = -10):
         self.use_gpu = use_gpu
         self.transform_matrices = []
         self.axis = axis
-        self.degree = np.array(degree)
+        self.degree = np.array((math.radians(degree[0]), math.radians(degree[1]), math.radians(degree[2])))
         self.scale = np.array(scale)
         self.device = device
         self.is_random = is_random
+        self.pad_value = pad_value
 
     def get_matrices_and_coords(self, images):
         if len(images.shape) == 5:
@@ -42,27 +44,19 @@ class Batch_Affine_3D(object):
 
         for batch_index in range(bs):
             transformed_coords = self.gpu_calculate_coornidates(self.coords, self.matrices, img_size).long() #coorniates를 Affine 변환
+            padding_tuple = (torch.where(transformed_coords == -1)[-3].long(), torch.where(transformed_coords == -1)[-2].long(), torch.where(transformed_coords == -1)[-1].long())
             if not seg:
                 images[batch_index, :, :, :, :] = images[batch_index, :, transformed_coords[0], transformed_coords[1], transformed_coords[2]]
                 images = images.reshape(bs, n_modalities, nx, ny, nz)
+                for nm in range(n_modalities):
+                    images[batch_index][nm][padding_tuple] = self.pad_value
             else:
                 images[batch_index, :, :, :] = images[batch_index, transformed_coords[0], transformed_coords[1], transformed_coords[2]]
                 images = images.reshape(bs, nx, ny, nz)
+                images[batch_index][padding_tuple] = 0
             
         return images
 
-    def pad_image_seg(self, images, patch_size): #patch size보다 전체 이미지 크기가 작을 경우 padding을 진
-        image_shape = np.array((images.shape[-3], images.shape[-2], images.shape[-1]))
-        patch_size = np.array(patch_size)
-        if np.any(image_shape <patch_size):
-            odd_pad = ((patch_size - image_shape) % 2 != 0).astype(int)
-            even_pad = np.repeat(np.clip(((patch_size - image_shape)/2).astype(int), 0, np.inf), 2)
-            for i in range(len(odd_pad)):
-                even_pad[i*2] += odd_pad[i]
-            even_pad = tuple(even_pad[::-1].astype(int).copy())
-            images = F.pad(images, even_pad, "constant", 0 )
-        print(image_shape, patch_size, images.shape)
-        return images
 
     def set_rotate_matrix(self, axis, degree):
         function_list = [self.rotation_x_3d, self.rotation_y_3d, self.rotation_z_3d]
@@ -87,21 +81,21 @@ class Batch_Affine_3D(object):
         return torch.vstack((grid_x.unsqueeze_(0), grid_y.unsqueeze_(0), grid_z.unsqueeze_(0)))
     
     def set_random_scale_degree(self):
-        degree = np.random.uniform(3) < 0.5
-        if self.is_random:
+        temp = np.random.uniform(0, 1)
+        if temp < 0.4:
             degree = np.random.uniform( size = self.degree.shape) * self.degree
             degree = (np.random.uniform(size = 3) < 0.5).astype(int) * degree
-            if np.any(self.scale):
-                scale = np.random.uniform(low = self.scale[0], high = self.scale[1], size = (1,3))
-            else:
-                scale = 1
-            return scale, degree
-    
-        else:
-            degree = np.array(self.degree)
             scale = 1
-            return degree, scale
-
+            
+        elif temp < 0.8:
+            scale = np.random.uniform(low = self.scale[0], high = self.scale[1], size = 1)[0]
+            degree = np.array([0,0,0])
+        else:
+            scale = np.random.uniform(low = self.scale[0], high = self.scale[1], size = 1)[0]
+            degree = np.random.uniform( size = self.degree.shape) * self.degree
+            degree = (np.random.uniform(size = 3) < 0.5).astype(int) * degree
+            
+        return scale, degree
     def get_matrices(self):
         transform_matrices = []
         scale, degree = self.set_random_scale_degree()
@@ -128,8 +122,13 @@ class Batch_Affine_3D(object):
         coords = torch.matmul(matrices[-1], coords.reshape(3, -1)).reshape(*before_shape)
         coords = coords + half_img_size
         coords = coords.reshape(3, -1).round() #Mapping 해주는 함수
-        coords = torch.min(torch.max(coords,  torch.Tensor([[0], [0], [0]]).long().to(self.device)) ,torch.Tensor(coords_bound).long().to(self.device)).long()
-
+        
+        coords[coords < 0 ] = -1
+        coords[-3][coords[-3] > img_size[-3] - 2] = -1
+        coords[-2][coords[-2] > img_size[-2] - 2] = -1
+        coords[-1][coords[-1] > img_size[-1] - 2] = -1
+        #coords = torch.min(torch.max(coords,  torch.Tensor([[0], [0], [0]]).long().to(self.device)) ,torch.Tensor(coords_bound).long().to(self.device)).long()
+        
         return coords.reshape(*before_shape)
 
 
@@ -216,6 +215,7 @@ class Batch_Brightness(object):
         return images * x
 
 
+
 class Batch_GammaTransform(object):
     def __init__(self, gamma_range = (0.5, 2), epsilon = 1e-7, device = None, retain_stats = True):
         self.gamma_range = gamma_range
@@ -290,14 +290,15 @@ class Batch_Mirroring(object):
 
     def get_mirror_axis(self):
         do_mirror = np.random.uniform(0,1, size = 3)
+        max_value = np.max(do_mirror)
         self.mirror_axis = []
-        if do_mirror[0] < self.x_prob:
+        if do_mirror[0] == max_value:
             self.mirror_axis.append(-3)
         
-        if do_mirror[1] < self.y_prob:
+        if do_mirror[1] == max_value:
             self.mirror_axis.append(-2)
         
-        if do_mirror[2] < self.z_prob:
+        if do_mirror[2] == max_value:
             self.mirror_axis.append(-1)
 
 
@@ -307,4 +308,17 @@ class Batch_Mirroring(object):
         
         else:
             return images
-        
\ No newline at end of file
+
+class Batch_Low_Resolution(object):
+    def __init__(self, prob = 0.5):
+        self.prob_per_modality = 0.5
+
+    def __call__(self, images):
+        modality_size = images.shape[1]
+        do_per_modality = np.random.uniform(0,1, size = modality_size)
+        for i in range(modality_size):
+            if do_per_modality[i] > self.prob_per_modality:
+                continue
+            images[:, i] = F.interpolate(F.interpolate(images[:, i].unsqueeze(0), scale_factor = 0.5, mode ='trilinear', recompute_scale_factor=True, align_corners = True), scale_factor = 2.0, mode ='trilinear',recompute_scale_factor=True, align_corners = True).squeeze(0)
+        
+        return images
\ No newline at end of file
